@@ -24,23 +24,31 @@ from google.cloud.datacatalog_v1beta1.proto.tags_pb2 import FieldType, TagField,
 from airflow import models
 from airflow.operators.bash_operator import BashOperator
 from airflow.providers.google.cloud.operators.datacatalog import (
-    CloudDataCatalogCreateEntryGroupOperator, CloudDataCatalogCreateEntryOperator,
-    CloudDataCatalogCreateTagOperator, CloudDataCatalogCreateTagTemplateFieldOperator,
-    CloudDataCatalogCreateTagTemplateOperator, CloudDataCatalogDeleteEntryGroupOperator,
-    CloudDataCatalogDeleteEntryOperator, CloudDataCatalogDeleteTagOperator,
-    CloudDataCatalogDeleteTagTemplateFieldOperator, CloudDataCatalogDeleteTagTemplateOperator,
-    CloudDataCatalogGetEntryGroupOperator, CloudDataCatalogGetEntryOperator,
-    CloudDataCatalogGetTagTemplateOperator, CloudDataCatalogListTagsOperator,
-    CloudDataCatalogLookupEntryOperator, CloudDataCatalogRenameTagTemplateFieldOperator,
-    CloudDataCatalogSearchCatalogOperator, CloudDataCatalogUpdateEntryOperator,
-    CloudDataCatalogUpdateTagOperator, CloudDataCatalogUpdateTagTemplateFieldOperator,
+    CloudDataCatalogCreateEntryGroupOperator,
+    CloudDataCatalogCreateEntryOperator,
+    CloudDataCatalogCreateTagOperator,
+    CloudDataCatalogCreateTagTemplateFieldOperator,
+    CloudDataCatalogCreateTagTemplateOperator,
+    CloudDataCatalogDeleteEntryGroupOperator,
+    CloudDataCatalogDeleteEntryOperator,
+    CloudDataCatalogDeleteTagOperator,
+    CloudDataCatalogDeleteTagTemplateFieldOperator,
+    CloudDataCatalogDeleteTagTemplateOperator,
+    CloudDataCatalogGetEntryGroupOperator,
+    CloudDataCatalogGetEntryOperator,
+    CloudDataCatalogGetTagTemplateOperator,
+    CloudDataCatalogListTagsOperator,
+    CloudDataCatalogLookupEntryOperator,
+    CloudDataCatalogRenameTagTemplateFieldOperator,
+    CloudDataCatalogSearchCatalogOperator,
+    CloudDataCatalogUpdateEntryOperator,
+    CloudDataCatalogUpdateTagOperator,
+    CloudDataCatalogUpdateTagTemplateFieldOperator,
     CloudDataCatalogUpdateTagTemplateOperator,
 )
 from airflow.utils.dates import days_ago
 from airflow.providers.google.common.utils.helpers import chain
 
-default_args = {"start_date": days_ago(1)}
-
 PROJECT_ID = "polidea-airflow"
 LOCATION = "us-central1"
 ENTRY_GROUP_ID = "important_data_jan_2019"
@@ -50,7 +58,7 @@ FIELD_NAME_1 = "first"
 FIELD_NAME_2 = "second"
 FIELD_NAME_3 = "first-rename"
 
-with models.DAG("example_gcp_datacatalog", default_args=default_args, schedule_interval=None) as dag:
+with models.DAG("example_gcp_datacatalog", start_date=days_ago(1), schedule_interval=None) as dag:
     # Create
     # [START howto_operator_gcp_datacatalog_create_entry_group]
     create_entry_group = CloudDataCatalogCreateEntryGroupOperator(
@@ -290,7 +298,7 @@ with models.DAG("example_gcp_datacatalog", default_args=default_args, schedule_i
         task_id="lookup_entry",
         linked_resource=current_entry_template.format(
             project_id=PROJECT_ID, location=LOCATION, entry_group=ENTRY_GROUP_ID, entry=ENTRY_ID
-        )
+        ),
     )
     # [END howto_operator_gcp_datacatalog_lookup_entry_linked_resource]
 
