@@ -21,7 +21,7 @@ This module contains Google DataFusion hook.
 import json
 import os
 from time import monotonic, sleep
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Sequence, Union
 from urllib.parse import quote, urlencode
 
 import google.auth
@@ -64,8 +64,13 @@ class DataFusionHook(GoogleBaseHook):
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
         delegate_to: Optional[str] = None,
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
     ) -> None:
-        super().__init__(gcp_conn_id, delegate_to)
+        super().__init__(
+            gcp_conn_id=gcp_conn_id,
+            delegate_to=delegate_to,
+            impersonation_chain=impersonation_chain,
+        )
         self.api_version = api_version
 
     def wait_for_operation(self, operation: Dict[str, Any]) -> Dict[str, Any]:
@@ -100,26 +105,27 @@ class DataFusionHook(GoogleBaseHook):
     ):
         """
         Polls pipeline state and raises an exception if the state is one of
-        `failure_states` or the operation timeouted.
+        `failure_states` or the operation timed_out.
         """
         failure_states = failure_states or FAILURE_STATES
         success_states = success_states or SUCCESS_STATES
         start_time = monotonic()
         current_state = None
         while monotonic() - start_time < timeout:
-            current_state = self._get_workflow_state(
-                pipeline_name=pipeline_name,
-                pipeline_id=pipeline_id,
-                instance_url=instance_url,
-                namespace=namespace,
-            )
-
+            try:
+                current_state = self._get_workflow_state(
+                    pipeline_name=pipeline_name,
+                    pipeline_id=pipeline_id,
+                    instance_url=instance_url,
+                    namespace=namespace,
+                )
+            except AirflowException:
+                pass  # Because the pipeline may not be visible in system yet
             if current_state in success_states:
                 return
             if current_state in failure_states:
                 raise AirflowException(
-                    f"Pipeline {pipeline_name} state {current_state} is not "
-                    f"one of {success_states}"
+                    f"Pipeline {pipeline_name} state {current_state} is not " f"one of {success_states}"
                 )
             sleep(30)
 
@@ -139,9 +145,7 @@ class DataFusionHook(GoogleBaseHook):
 
     @staticmethod
     def _base_url(instance_url: str, namespace: str) -> str:
-        return os.path.join(
-            instance_url, "v3", "namespaces", quote(namespace), "apps"
-        )
+        return os.path.join(instance_url, "v3", "namespaces", quote(namespace), "apps")
 
     def _cdap_request(
         self, url: str, method: str, body: Optional[Union[List, Dict]] = None
@@ -150,9 +154,7 @@ class DataFusionHook(GoogleBaseHook):
         request = google.auth.transport.requests.Request()
 
         credentials = self._get_credentials()
-        credentials.before_request(
-            request=request, method=method, url=url, headers=headers
-        )
+        credentials.before_request(request=request, method=method, url=url, headers=headers)
 
         payload = json.dumps(body) if body else None
 
@@ -174,9 +176,7 @@ class DataFusionHook(GoogleBaseHook):
         return self._conn
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def restart_instance(
-        self, instance_name: str, location: str, project_id: str
-    ) -> Operation:
+    def restart_instance(self, instance_name: str, location: str, project_id: str) -> Operation:
         """
         Restart a single Data Fusion instance.
         At the end of an operation instance is fully restarted.
@@ -185,7 +185,7 @@ class DataFusionHook(GoogleBaseHook):
         :type instance_name: str
         :param location: The Cloud Data Fusion location in which to handle the request.
         :type location: str
-        :param project_id: The ID of the Google Cloud Platform project that the instance belongs to.
+        :param project_id: The ID of the Google Cloud project that the instance belongs to.
         :type project_id: str
         """
         operation = (
@@ -199,9 +199,7 @@ class DataFusionHook(GoogleBaseHook):
         return operation
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def delete_instance(
-        self, instance_name: str, location: str, project_id: str
-    ) -> Operation:
+    def delete_instance(self, instance_name: str, location: str, project_id: str) -> Operation:
         """
         Deletes a single Date Fusion instance.
 
@@ -209,7 +207,7 @@ class DataFusionHook(GoogleBaseHook):
         :type instance_name: str
         :param location: The Cloud Data Fusion location in which to handle the request.
         :type location: str
-        :param project_id: The ID of the Google Cloud Platform project that the instance belongs to.
+        :param project_id: The ID of the Google Cloud project that the instance belongs to.
         :type project_id: str
         """
         operation = (
@@ -240,7 +238,7 @@ class DataFusionHook(GoogleBaseHook):
         :type instance: Dict[str, Any]
         :param location: The Cloud Data Fusion location in which to handle the request.
         :type location: str
-        :param project_id: The ID of the Google Cloud Platform project that the instance belongs to.
+        :param project_id: The ID of the Google Cloud project that the instance belongs to.
         :type project_id: str
         """
         operation = (
@@ -258,9 +256,7 @@ class DataFusionHook(GoogleBaseHook):
         return operation
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def get_instance(
-        self, instance_name: str, location: str, project_id: str
-    ) -> Dict[str, Any]:
+    def get_instance(self, instance_name: str, location: str, project_id: str) -> Dict[str, Any]:
         """
         Gets details of a single Data Fusion instance.
 
@@ -268,7 +264,7 @@ class DataFusionHook(GoogleBaseHook):
         :type instance_name: str
         :param location: The Cloud Data Fusion location in which to handle the request.
         :type location: str
-        :param project_id: The ID of the Google Cloud Platform project that the instance belongs to.
+        :param project_id: The ID of the Google Cloud project that the instance belongs to.
         :type project_id: str
         """
         instance = (
@@ -307,7 +303,7 @@ class DataFusionHook(GoogleBaseHook):
         :type update_mask: str
         :param location: The Cloud Data Fusion location in which to handle the request.
         :type location: str
-        :param project_id: The ID of the Google Cloud Platform project that the instance belongs to.
+        :param project_id: The ID of the Google Cloud project that the instance belongs to.
         :type project_id: str
         """
         operation = (
@@ -349,9 +345,7 @@ class DataFusionHook(GoogleBaseHook):
         url = os.path.join(self._base_url(instance_url, namespace), quote(pipeline_name))
         response = self._cdap_request(url=url, method="PUT", body=pipeline)
         if response.status != 200:
-            raise AirflowException(
-                f"Creating a pipeline failed with code {response.status}"
-            )
+            raise AirflowException(f"Creating a pipeline failed with code {response.status}")
 
     def delete_pipeline(
         self,
@@ -380,9 +374,7 @@ class DataFusionHook(GoogleBaseHook):
 
         response = self._cdap_request(url=url, method="DELETE", body=None)
         if response.status != 200:
-            raise AirflowException(
-                f"Deleting a pipeline failed with code {response.status}"
-            )
+            raise AirflowException(f"Deleting a pipeline failed with code {response.status}")
 
     def list_pipelines(
         self,
@@ -416,9 +408,7 @@ class DataFusionHook(GoogleBaseHook):
 
         response = self._cdap_request(url=url, method="GET", body=None)
         if response.status != 200:
-            raise AirflowException(
-                f"Listing pipelines failed with code {response.status}"
-            )
+            raise AirflowException(f"Listing pipelines failed with code {response.status}")
         return json.loads(response.data)
 
     def _get_workflow_state(
@@ -438,9 +428,7 @@ class DataFusionHook(GoogleBaseHook):
         )
         response = self._cdap_request(url=url, method="GET")
         if response.status != 200:
-            raise AirflowException(
-                f"Retrieving a pipeline state failed with code {response.status}"
-            )
+            raise AirflowException(f"Retrieving a pipeline state failed with code {response.status}")
         workflow = json.loads(response.data)
         return workflow["status"]
 
@@ -476,17 +464,17 @@ class DataFusionHook(GoogleBaseHook):
             "start",
         )
         runtime_args = runtime_args or {}
-        body = [{
-            "appId": pipeline_name,
-            "programType": "workflow",
-            "programId": "DataPipelineWorkflow",
-            "runtimeargs": runtime_args
-        }]
+        body = [
+            {
+                "appId": pipeline_name,
+                "programType": "workflow",
+                "programId": "DataPipelineWorkflow",
+                "runtimeargs": runtime_args,
+            }
+        ]
         response = self._cdap_request(url=url, method="POST", body=body)
         if response.status != 200:
-            raise AirflowException(
-                f"Starting a pipeline failed with code {response.status}"
-            )
+            raise AirflowException(f"Starting a pipeline failed with code {response.status}")
 
         response_json = json.loads(response.data)
         pipeline_id = response_json[0]["runId"]
@@ -499,9 +487,7 @@ class DataFusionHook(GoogleBaseHook):
         )
         return pipeline_id
 
-    def stop_pipeline(
-        self, pipeline_name: str, instance_url: str, namespace: str = "default"
-    ) -> None:
+    def stop_pipeline(self, pipeline_name: str, instance_url: str, namespace: str = "default") -> None:
         """
         Stops a Cloud Data Fusion pipeline. Works for both batch and stream pipelines.
 
@@ -523,6 +509,4 @@ class DataFusionHook(GoogleBaseHook):
         )
         response = self._cdap_request(url=url, method="POST")
         if response.status != 200:
-            raise AirflowException(
-                f"Stopping a pipeline failed with code {response.status}"
-            )
+            raise AirflowException(f"Stopping a pipeline failed with code {response.status}")
