@@ -18,12 +18,15 @@
 """
 This module contains a Google Cloud Text to Speech Hook.
 """
-from typing import Dict, Optional, Union
+from typing import Dict, Optional, Sequence, Union
 
 from google.api_core.retry import Retry
 from google.cloud.texttospeech_v1 import TextToSpeechClient
 from google.cloud.texttospeech_v1.types import (
-    AudioConfig, SynthesisInput, SynthesizeSpeechResponse, VoiceSelectionParams,
+    AudioConfig,
+    SynthesisInput,
+    SynthesizeSpeechResponse,
+    VoiceSelectionParams,
 )
 
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
@@ -38,14 +41,32 @@ class CloudTextToSpeechHook(GoogleBaseHook):
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :type gcp_conn_id: str
-    :param delegate_to: The account to impersonate, if any.
-        For this to work, the service account making the request must have
+    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
+        if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
     :type delegate_to: str
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account.
+    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    def __init__(self, gcp_conn_id: str = "google_cloud_default", delegate_to: Optional[str] = None) -> None:
-        super().__init__(gcp_conn_id, delegate_to)
+    def __init__(
+        self,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: Optional[str] = None,
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+    ) -> None:
+        super().__init__(
+            gcp_conn_id=gcp_conn_id,
+            delegate_to=delegate_to,
+            impersonation_chain=impersonation_chain,
+        )
         self._client = None  # type: Optional[TextToSpeechClient]
 
     def get_conn(self) -> TextToSpeechClient:
@@ -58,8 +79,7 @@ class CloudTextToSpeechHook(GoogleBaseHook):
         if not self._client:
             # pylint: disable=unexpected-keyword-arg
             self._client = TextToSpeechClient(
-                credentials=self._get_credentials(),
-                client_info=self.client_info
+                credentials=self._get_credentials(), client_info=self.client_info
             )
             # pylint: enable=unexpected-keyword-arg
 
@@ -72,7 +92,7 @@ class CloudTextToSpeechHook(GoogleBaseHook):
         voice: Union[Dict, VoiceSelectionParams],
         audio_config: Union[Dict, AudioConfig],
         retry: Optional[Retry] = None,
-        timeout: Optional[float] = None
+        timeout: Optional[float] = None,
     ) -> SynthesizeSpeechResponse:
         """
         Synthesizes text input
