@@ -26,23 +26,26 @@ from cached_property import cached_property
 from google.api_core.retry import Retry
 from google.cloud.vision_v1 import ImageAnnotatorClient, ProductSearchClient
 from google.cloud.vision_v1.types import (
-    AnnotateImageRequest, FieldMask, Image, Product, ProductSet, ReferenceImage,
+    AnnotateImageRequest,
+    FieldMask,
+    Image,
+    Product,
+    ProductSet,
+    ReferenceImage,
 )
 from google.protobuf.json_format import MessageToDict
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
-ERR_DIFF_NAMES = \
-    """The {label} name provided in the object ({explicit_name}) is different than the name created
-    from the input parameters ({constructed_name}). Please either:
+ERR_DIFF_NAMES = """The {label} name provided in the object ({explicit_name}) is different
+    than the name created from the input parameters ({constructed_name}). Please either:
     1) Remove the {label} name,
     2) Remove the location and {id_label} parameters,
     3) Unify the {label} name and input parameters.
     """
 
-ERR_UNABLE_TO_CREATE = \
-    """Unable to determine the {label} name. Please either set the name directly
+ERR_UNABLE_TO_CREATE = """Unable to determine the {label} name. Please either set the name directly
     in the {label} object or provide the `location` and `{id_label}` parameters.
     """
 
@@ -51,17 +54,14 @@ class NameDeterminer:
     """
     Helper class to determine entity name.
     """
+
     def __init__(self, label: str, id_label: str, get_path: Callable[[str, str, str], str]) -> None:
         self.label = label
         self.id_label = id_label
         self.get_path = get_path
 
     def get_entity_with_name(
-        self,
-        entity: Any,
-        entity_id: Optional[str],
-        location: Optional[str],
-        project_id: str
+        self, entity: Any, entity_id: Optional[str], location: Optional[str], project_id: str
     ) -> Any:
         """
         Check if entity has the `name` attribute set:
@@ -100,20 +100,20 @@ class NameDeterminer:
                 return entity
 
             if explicit_name != constructed_name:
-                raise AirflowException(ERR_DIFF_NAMES.format(
-                    label=self.label,
-                    explicit_name=explicit_name,
-                    constructed_name=constructed_name,
-                    id_label=self.id_label)
+                raise AirflowException(
+                    ERR_DIFF_NAMES.format(
+                        label=self.label,
+                        explicit_name=explicit_name,
+                        constructed_name=constructed_name,
+                        id_label=self.id_label,
+                    )
                 )
 
         # Not enough parameters to construct the name. Trying to use the name from Product / ProductSet.
         if explicit_name:
             return entity
         else:
-            raise AirflowException(
-                ERR_UNABLE_TO_CREATE.format(label=self.label, id_label=self.id_label)
-            )
+            raise AirflowException(ERR_UNABLE_TO_CREATE.format(label=self.label, id_label=self.id_label))
 
 
 class CloudVisionHook(GoogleBaseHook):
@@ -129,8 +129,17 @@ class CloudVisionHook(GoogleBaseHook):
         'ProductSet', 'productset_id', ProductSearchClient.product_set_path
     )
 
-    def __init__(self, gcp_conn_id: str = 'google_cloud_default', delegate_to: Optional[str] = None) -> None:
-        super().__init__(gcp_conn_id, delegate_to)
+    def __init__(
+        self,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: Optional[str] = None,
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+    ) -> None:
+        super().__init__(
+            gcp_conn_id=gcp_conn_id,
+            delegate_to=delegate_to,
+            impersonation_chain=impersonation_chain,
+        )
         self._client = None
 
     def get_conn(self) -> ProductSearchClient:
@@ -142,8 +151,7 @@ class CloudVisionHook(GoogleBaseHook):
         """
         if not self._client:
             self._client = ProductSearchClient(
-                credentials=self._get_credentials(),
-                client_info=self.client_info
+                credentials=self._get_credentials(), client_info=self.client_info
             )
         return self._client
 
@@ -205,7 +213,8 @@ class CloudVisionHook(GoogleBaseHook):
         product_set_id: str,
         project_id: str,
         retry: Optional[Retry] = None,
-        timeout: Optional[float] = None, metadata: Optional[Sequence[Tuple[str, str]]] = None
+        timeout: Optional[float] = None,
+        metadata: Optional[Sequence[Tuple[str, str]]] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -255,7 +264,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None
+        metadata: Optional[Sequence[Tuple[str, str]]] = None,
     ):
         """
         For the documentation see:
@@ -276,7 +285,7 @@ class CloudVisionHook(GoogleBaseHook):
         product_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None
+        metadata: Optional[Sequence[Tuple[str, str]]] = None,
     ):
         """
         For the documentation see:
@@ -311,7 +320,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None
+        metadata: Optional[Sequence[Tuple[str, str]]] = None,
     ):
         """
         For the documentation see:
@@ -359,7 +368,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None
+        metadata: Optional[Sequence[Tuple[str, str]]] = None,
     ):
         """
         For the documentation see:
@@ -385,7 +394,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> str:
         """
         For the documentation see:
-        :py:class:`~airflow.contrib.operators.gcp_vision_operator.CloudVisionReferenceImageCreateOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateReferenceImageOperator`
         """
         client = self.get_conn()
         self.log.info('Creating ReferenceImage')
@@ -425,17 +434,20 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> Dict:
         """
         For the documentation see:
-        :py:class:`~airflow.contrib.operators.gcp_vision_operator.CloudVisionReferenceImageCreateOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteReferenceImageOperator`
         """
         client = self.get_conn()
         self.log.info('Deleting ReferenceImage')
         name = ProductSearchClient.reference_image_path(
             project=project_id, location=location, product=product_id, reference_image=reference_image_id
         )
-        response = client.delete_reference_image(name=name,  # pylint: disable=assignment-from-no-return
-                                                 retry=retry,
-                                                 timeout=timeout,
-                                                 metadata=metadata)
+        # pylint: disable=assignment-from-no-return
+        response = client.delete_reference_image(
+            name=name,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         self.log.info('ReferenceImage with the name [%s] deleted.', name)
         return MessageToDict(response)
@@ -500,7 +512,7 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         request: Union[dict, AnnotateImageRequest],
         retry: Optional[Retry] = None,
-        timeout: Optional[float] = None
+        timeout: Optional[float] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -522,7 +534,7 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         requests: Union[List[dict], List[AnnotateImageRequest]],
         retry: Optional[Retry] = None,
-        timeout: Optional[float] = None
+        timeout: Optional[float] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -532,9 +544,9 @@ class CloudVisionHook(GoogleBaseHook):
 
         self.log.info('Annotating images')
 
-        response = client.batch_annotate_images(requests=requests,  # pylint: disable=no-member
-                                                retry=retry,
-                                                timeout=timeout)
+        response = client.batch_annotate_images(
+            requests=requests, retry=retry, timeout=timeout  # pylint: disable=no-member
+        )
 
         self.log.info('Images annotated')
 
@@ -547,7 +559,7 @@ class CloudVisionHook(GoogleBaseHook):
         max_results: Optional[int] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None
+        additional_properties: Optional[Dict] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -577,7 +589,7 @@ class CloudVisionHook(GoogleBaseHook):
         max_results: Optional[int] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None
+        additional_properties: Optional[Dict] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -607,7 +619,7 @@ class CloudVisionHook(GoogleBaseHook):
         max_results: Optional[int] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None
+        additional_properties: Optional[Dict] = None,
     ) -> Dict:
         """
         For the documentation see:
@@ -637,7 +649,7 @@ class CloudVisionHook(GoogleBaseHook):
         max_results: Optional[int] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None
+        additional_properties: Optional[Dict] = None,
     ) -> Dict:
         """
         For the documentation see:
