@@ -15,11 +15,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Operators that integrat with Google Cloud Build service."""
+"""Operators that integrate with Google Cloud Build service."""
 import json
 import re
 from copy import deepcopy
-from typing import Any, Dict, Iterable, Optional, Union
+from typing import Any, Dict, Optional, Sequence, Union
 from urllib.parse import unquote, urlparse
 
 import yaml
@@ -174,23 +174,41 @@ class CloudBuildCreateBuildOperator(BaseOperator):
     :param project_id: ID of the Google Cloud project if None then
         default project_id is used.
     :type project_id: str
-    :param gcp_conn_id: The connection ID to use to connect to Google Cloud Platform.
+    :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
     :type gcp_conn_id: str
     :param api_version: API version used (for example v1 or v1beta1).
     :type api_version: str
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = ("body", "gcp_conn_id", "api_version")  # type: Iterable[str]
+    template_fields = (
+        "body",
+        "gcp_conn_id",
+        "api_version",
+        "impersonation_chain",
+    )
     template_ext = ['.yml', '.yaml', '.json']
 
     @apply_defaults
-    def __init__(self,
-                 body: Union[dict, str],
-                 project_id: Optional[str] = None,
-                 gcp_conn_id: str = "google_cloud_default",
-                 api_version: str = "v1",
-                 *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
+    def __init__(
+        self,
+        *,
+        body: Union[dict, str],
+        project_id: Optional[str] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        api_version: str = "v1",
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
         self.body = body
         # Not template fields to keep original value
         self.body_raw = body
@@ -198,6 +216,7 @@ class CloudBuildCreateBuildOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.api_version = api_version
         self._validate_inputs()
+        self.impersonation_chain = impersonation_chain
 
     def prepare_template(self) -> None:
         # if no file is specified, skip
@@ -214,6 +233,10 @@ class CloudBuildCreateBuildOperator(BaseOperator):
             raise AirflowException("The required parameter 'body' is missing")
 
     def execute(self, context):
-        hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, api_version=self.api_version)
+        hook = CloudBuildHook(
+            gcp_conn_id=self.gcp_conn_id,
+            api_version=self.api_version,
+            impersonation_chain=self.impersonation_chain,
+        )
         body = BuildProcessor(body=self.body).process_body()
         return hook.create_build(body=body, project_id=self.project_id)
