@@ -22,7 +22,7 @@ This module contains Google Kubernetes Engine operators.
 
 import os
 import tempfile
-from typing import Dict, Optional, Union
+from typing import Dict, Optional, Sequence, Union
 
 from google.cloud.container_v1.types import Cluster
 
@@ -65,39 +65,63 @@ class GKEDeleteClusterOperator(BaseOperator):
     :param location: The name of the Google Compute Engine zone in which the cluster
         resides.
     :type location: str
-    :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
+    :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :type gcp_conn_id: str
     :param api_version: The api version to use
     :type api_version: str
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    :type impersonation_chain: Union[str, Sequence[str]]
     """
-    template_fields = ['project_id', 'gcp_conn_id', 'name', 'location', 'api_version']
+
+    template_fields = [
+        'project_id',
+        'gcp_conn_id',
+        'name',
+        'location',
+        'api_version',
+        'impersonation_chain',
+    ]
 
     @apply_defaults
-    def __init__(self,
-                 name: str,
-                 location: str,
-                 project_id: Optional[str] = None,
-                 gcp_conn_id: str = 'google_cloud_default',
-                 api_version: str = 'v2',
-                 *args,
-                 **kwargs) -> None:
-        super().__init__(*args, **kwargs)
+    def __init__(
+        self,
+        *,
+        name: str,
+        location: str,
+        project_id: Optional[str] = None,
+        gcp_conn_id: str = 'google_cloud_default',
+        api_version: str = 'v2',
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
 
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
         self.location = location
         self.api_version = api_version
         self.name = name
+        self.impersonation_chain = impersonation_chain
         self._check_input()
 
     def _check_input(self):
         if not all([self.project_id, self.name, self.location]):
-            self.log.error(
-                'One of (project_id, name, location) is missing or incorrect')
+            self.log.error('One of (project_id, name, location) is missing or incorrect')
             raise AirflowException('Operator has incorrect or missing input.')
 
     def execute(self, context):
-        hook = GKEHook(gcp_conn_id=self.gcp_conn_id, location=self.location)
+        hook = GKEHook(
+            gcp_conn_id=self.gcp_conn_id,
+            location=self.location,
+            impersonation_chain=self.impersonation_chain,
+        )
         delete_result = hook.delete_cluster(name=self.name, project_id=self.project_id)
         return delete_result
 
@@ -144,35 +168,56 @@ class GKECreateClusterOperator(BaseOperator):
     :param body: The Cluster definition to create, can be protobuf or python dict, if
         dict it must match protobuf message Cluster
     :type body: dict or google.cloud.container_v1.types.Cluster
-    :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
+    :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :type gcp_conn_id: str
     :param api_version: The api version to use
     :type api_version: str
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    :type impersonation_chain: Union[str, Sequence[str]]
     """
-    template_fields = ['project_id', 'gcp_conn_id', 'location', 'api_version', 'body']
+
+    template_fields = [
+        'project_id',
+        'gcp_conn_id',
+        'location',
+        'api_version',
+        'body',
+        'impersonation_chain',
+    ]
 
     @apply_defaults
-    def __init__(self,
-                 location: str,
-                 body: Optional[Union[Dict, Cluster]],
-                 project_id: Optional[str] = None,
-                 gcp_conn_id: str = 'google_cloud_default',
-                 api_version: str = 'v2',
-                 *args,
-                 **kwargs) -> None:
-        super().__init__(*args, **kwargs)
+    def __init__(
+        self,
+        *,
+        location: str,
+        body: Optional[Union[Dict, Cluster]],
+        project_id: Optional[str] = None,
+        gcp_conn_id: str = 'google_cloud_default',
+        api_version: str = 'v2',
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
 
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
         self.location = location
         self.api_version = api_version
         self.body = body
+        self.impersonation_chain = impersonation_chain
         self._check_input()
 
     def _check_input(self):
         if not all([self.project_id, self.location, self.body]) or not (
-            (isinstance(self.body, dict) and "name" in self.body and "initial_node_count" in self.body) or
-            (getattr(self.body, "name", None) and getattr(self.body, "initial_node_count", None))
+            (isinstance(self.body, dict) and "name" in self.body and "initial_node_count" in self.body)
+            or (getattr(self.body, "name", None) and getattr(self.body, "initial_node_count", None))
         ):
             self.log.error(
                 "One of (project_id, location, body, body['name'], "
@@ -181,7 +226,11 @@ class GKECreateClusterOperator(BaseOperator):
             raise AirflowException("Operator has incorrect or missing input.")
 
     def execute(self, context):
-        hook = GKEHook(gcp_conn_id=self.gcp_conn_id, location=self.location)
+        hook = GKEHook(
+            gcp_conn_id=self.gcp_conn_id,
+            location=self.location,
+            impersonation_chain=self.impersonation_chain,
+        )
         create_op = hook.create_cluster(cluster=self.body, project_id=self.project_id)
         return create_op
 
